An S4 class to represent the files within a simulation or simulations.
Created using the getFiles method. Specific files within the class are modified
by the object with class SimulationFilter-class
1 2 3 | baseDir(x)
simulationFilter(x) <- value
|
simulationFiltercontains SimulationFilter-class object
filesa data.frame, with each row describing the file
sequenceInfoLista list, with each list element showing the variable permutation(s) within this specific simulation sequence.
sequenceInfoDfa data frame, with each row containing one simulation, and each column a parameter ('parametre') specific to the sequence. A condensed version of sequenceInfoList.
wavelengthsa data frame containing spectral information on each band for each simulation
sunAnglesa data frame containing sun angles straight from simulation.properties.txt
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.